@@ -1,7 +1,7 @@
 /************************************************************************
  * ifchk.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2014 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2015 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous  *
  *                  mode detection and handling.              *
  *                                                            *
- * Version:         1.0.0                                     *
+ * Version:         1.0.1                                     *
  *                                                            *
  * ---------------------------------------------------------- *
  *                                                            *
@@ -101,6 +101,9 @@ int main( int argc, char **argv )
     size_t pathLen = 0;			/* Pathname length. */
     struct fsObj fsObject;		/* For statFile(). */
     struct stat testAttrs;		/* Error log file attributes. */
+    char argBuf[STRBUFSZ];		/* Command line option buffer. */
+    char *wsPtr = NULL;			/* Ptr for trailing white space processing. */
+    int i = 1;				/* For argBuf[]. */
 
     /*
      * Reset all statFile() file checks.
@@ -257,12 +260,27 @@ int main( int argc, char **argv )
      * Report and log that we are start-
      * ing up as a foreground process.
      */
-    if( FFlag == TRUE )
+    memset( argBuf, '\000', sizeof( argBuf ) );
+
+    while( i < argc )
     {
-        printf( "ifchk[%d]: ifchk %s starting up\n", getpid(), VERS );
+        strncat( argBuf, argv[i], sizeof( argBuf ) );
+        strncat( argBuf, " ", sizeof( argBuf ) );
+
+	i++;
      }
 
-    if( ( writeLog( LOG_NOTICE, "ifchk %s starting up\n", VERS ) ) != 0 )
+    if( ( wsPtr = strrchr( argBuf, ' ' ) ) )
+    {
+        *wsPtr = '\000';
+     }
+
+    if( FFlag == TRUE )
+    {
+        printf( "ifchk[%d]: starting ifchk %s %s\n", getpid(), VERS, argBuf );
+     }
+
+    if( ( writeLog( LOG_NOTICE, "starting ifchk %s %s\n", VERS, argBuf ) ) != 0 )
     {
         exit( EXIT_FAILURE );
      }
